@@ -50,11 +50,12 @@ class GlobalOptions:
 
 @dataclass
 class GitOptions:
-    __slots__ = ("since_commit", "max_depth", "branch", "fetch")
+    __slots__ = ("since_commit", "max_depth", "branch", "fetch", "include_submodules")
     since_commit: Optional[str]
     max_depth: int
     branch: Optional[str]
     fetch: bool
+    include_submodules: bool
 
 
 class IssueType(enum.Enum):
